summaryrefslogtreecommitdiff
path: root/pango/pango-context.c
diff options
context:
space:
mode:
Diffstat (limited to 'pango/pango-context.c')
-rw-r--r--pango/pango-context.c11
1 files changed, 7 insertions, 4 deletions
diff --git a/pango/pango-context.c b/pango/pango-context.c
index 43a14b69..390d23a0 100644
--- a/pango/pango-context.c
+++ b/pango/pango-context.c
@@ -1091,15 +1091,18 @@ itemize_state_process_run (ItemizeState *state)
* emulated ideographic space for the primary font wouldn't be the
* right size.
*
* The exception of PrivateUse characters is indeed necessary to be
* able to render any of them.
*/
/*
if (G_UNLIKELY (!g_unichar_isgraph (wc) && wc != 0x3000 &&
- g_unichar_type (wc) != G_UNICODE_PRIVATE_USE))
+ g_unichar_type (wc) != G_UNICODE_PRIVATE_USE &&
+ g_unichar_type (wc) != G_UNICODE_UNASSIGNED))
*/
if (G_UNLIKELY (!g_unichar_isprint (wc) &&
- g_unichar_type (wc) != G_UNICODE_PRIVATE_USE))
+ g_unichar_type (wc) != G_UNICODE_PRIVATE_USE &&
+ g_unichar_type (wc) != G_UNICODE_UNASSIGNED))
{
shape_engine = NULL;
font = NULL;
@@ -1091,15 +1091,18 @@ itemize_state_process_run (ItemizeState *state)
* right size.
*
- * The exception of PrivateUse characters is indeed necessary to be
- * able to render any of them.
+ * The exception of PrivateUse and Unassigned characters is necessary
+ * to be able to render any of them. (for private or being encoded
+ * scripts, etc.)
*/
/*